# stayawake

A tool for keeping your computer awake.

## Installation

Install using pip:

~~~ bash
pip install stayawake
~~~

## Using from the command line:

~~~ bash
stayawake
~~~

Or specify the interval at which to move the cursor

~~~ bash
stayawake -i 5
~~~

## Updating Pypi

~~~ bash
pip install twine
python setup.py sdist bdist_wheel
~~~